==> deepin-screen-recorder_2.7.5.orig.tar.gz: deepin-screen-recorder-2.7.5/translations/deepin-screen-recorder_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
<context>
    <name>CountdownTooltip</name>
    <message>
        <location filename="../src/countdown_tooltip.cpp" line="73"/>
        <source>Click tray icon 
or press the shortcut again to stop recording</source>
        <translation>Clique no ícone da bandeja
ou pressione o atalho novamente para parar a gravação</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/main_window.cpp" line="67"/>
        <source>Deepin screen recorder</source>
        <translation>Deepin screen recorder</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="118"/>
        <source>Start recording</source>
        <translation>Começar gravação</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="387"/>
        <source>Select area</source>
        <translation>Selecionar área</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <location filename="../src/record_process.cpp" line="137"/>
        <source>deepin-screen-recorder</source>
        <translation>deepin-screen-recorder</translation>
    </message>
    <message>
        <location filename="../src/record_process.cpp" line="185"/>
        <source>View</source>
        <translation>Visualizar</translation>
    </message>
    <message>
        <location filename="../src/record_process.cpp" line="195"/>
        <source>Record finished</source>
        <translation>Gravação concluída</translation>
    </message>
    <message>
        <location filename="../src/record_process.cpp" line="196"/>
        <source>Saved to</source>
        <translation>Salvo em</translation>
    </message>
</context>
<context>
    <name>StartTooltip</name>
    <message>
        <location filename="../src/start_tooltip.cpp" line="45"/>
        <source>Click or drag to
select the area to record</source>
        <translation>Clique ou arraste para 
selecionar a área da gravação</translation>
    </message>
</context>
<context>
    <name>WindowManager</name>
    <message>
        <location filename="../src/window_manager.cpp" line="150"/>
        <location filename="../src/window_manager.cpp" line="169"/>
        <source>Desktop</source>
        <translation>Área de trabalho</translation>
    </message>
</context>
</TS>

==> deepin-screen-recorder_2.7.7.orig.tar.gz: deepin-screen-recorder-2.7.7/translations/deepin-screen-recorder_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
<context>
    <name>CountdownTooltip</name>
    <message>
        <location filename="../src/countdown_tooltip.cpp" line="73"/>
        <source>Click tray icon 
or press the shortcut again to stop recording</source>
        <translation>Clique no ícone da bandeja
ou pressione o atalho novamente para parar a gravação</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/main_window.cpp" line="67"/>
        <source>Deepin screen recorder</source>
        <translation>Gravador de Tela</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="121"/>
        <source>Start recording</source>
        <translation>Começar gravação</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="422"/>
        <source>Select area</source>
        <translation>Selecionar área</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <location filename="../src/record_process.cpp" line="137"/>
        <source>deepin-screen-recorder</source>
        <translation>gravador-de-tela</translation>
    </message>
    <message>
        <location filename="../src/record_process.cpp" line="185"/>
        <source>View</source>
        <translation>Visualizar</translation>
    </message>
    <message>
        <location filename="../src/record_process.cpp" line="195"/>
        <source>Record finished</source>
        <translation>Gravação concluída</translation>
    </message>
    <message>
        <location filename="../src/record_process.cpp" line="196"/>
        <source>Saved to</source>
        <translation>Salvo em</translation>
    </message>
</context>
<context>
    <name>StartTooltip</name>
    <message>
        <location filename="../src/start_tooltip.cpp" line="45"/>
        <source>Click or drag to
select the area to record</source>
        <translation>Clique ou arraste para 
selecionar a área da gravação</translation>
    </message>
</context>
<context>
    <name>WindowManager</name>
    <message>
        <location filename="../src/window_manager.cpp" line="150"/>
        <location filename="../src/window_manager.cpp" line="169"/>
        <source>Desktop</source>
        <translation>Área de trabalho</translation>
    </message>
</context>
</TS>
